==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/ByteHandler.h <==
// class gnu.java.beans.decoder.ByteHandler

// class file dependencies
// @dep_class 670cc122e6cfc20a gnu_java_beans_decoder_AbstractElementHandler
// @dep_class f70c8ec9a5c8db34 gnu_java_beans_decoder_ByteHandler
// @dep_class b0ac10a3c7037665 gnu_java_beans_decoder_SimpleHandler
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_SimpleHandler

#include "gnu/java/beans/decoder/SimpleHandler.h"

#ifndef _JC_gnu_java_beans_decoder_ByteHandler_H_
#define _JC_gnu_java_beans_decoder_ByteHandler_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_ByteHandler$sub_refs	_jc_gnu_java_beans_decoder_ByteHandler$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_ByteHandler$sub_nonrefs	_jc_gnu_java_beans_decoder_ByteHandler$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ByteHandler$refs	_jc_gnu_java_beans_decoder_ByteHandler$refs;
typedef struct _jc_gnu_java_beans_decoder_ByteHandler$nonrefs	_jc_gnu_java_beans_decoder_ByteHandler$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ByteHandler$object	_jc_gnu_java_beans_decoder_ByteHandler$object;

typedef const struct _jc_gnu_java_beans_decoder_ByteHandler$vmethods	_jc_gnu_java_beans_decoder_ByteHandler$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_ByteHandler$vtable	_jc_gnu_java_beans_decoder_ByteHandler$vtable;
typedef const struct _jc_gnu_java_beans_decoder_ByteHandler$vtype	_jc_gnu_java_beans_decoder_ByteHandler$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_ByteHandler$method$_init$7d8397207e40a3b4(_jc_env *, struct _jc_gnu_java_beans_decoder_ByteHandler$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_ByteHandler$method$parse$d4a2df662e34a121(_jc_env *, struct _jc_gnu_java_beans_decoder_ByteHandler$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_ByteHandler$method_info$parse$d4a2df662e34a121;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_ByteHandler$vmethods {
	struct _jc_java_lang_Object$object	*(*parse$d4a2df662e34a121)(_jc_env *, struct _jc_gnu_java_beans_decoder_ByteHandler$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_java_beans_decoder_ByteHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractElementHandler$vmethods	gnu_java_beans_decoder_AbstractElementHandler;
	_jc_gnu_java_beans_decoder_SimpleHandler$vmethods	gnu_java_beans_decoder_SimpleHandler;
	_jc_gnu_java_beans_decoder_ByteHandler$vmethods	gnu_java_beans_decoder_ByteHandler;
};

// Vtype
struct _jc_gnu_java_beans_decoder_ByteHandler$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_ByteHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ByteHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ByteHandler$refs {
    _jc_gnu_java_beans_decoder_ByteHandler$sub_refs	gnu_java_beans_decoder_ByteHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_refs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_refs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ByteHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ByteHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_nonrefs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_nonrefs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_ByteHandler$sub_nonrefs	gnu_java_beans_decoder_ByteHandler;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_ByteHandler$object {
	_jc_gnu_java_beans_decoder_ByteHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_ByteHandler$vtype	*vtype;
	_jc_gnu_java_beans_decoder_ByteHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_ByteHandler$vtype _jc_gnu_java_beans_decoder_ByteHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_ByteHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_ByteHandler$class_object;

#endif	/* _JC_gnu_java_beans_decoder_ByteHandler_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/ByteHandler.h <==
// class gnu.java.beans.decoder.ByteHandler

// class file dependencies
// @dep_class 670cc122e6cfc20a gnu_java_beans_decoder_AbstractElementHandler
// @dep_class f70c8ec9a5c8db34 gnu_java_beans_decoder_ByteHandler
// @dep_class b0ac10a3c7037665 gnu_java_beans_decoder_SimpleHandler
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_SimpleHandler

#include "gnu/java/beans/decoder/SimpleHandler.h"

#ifndef _JC_gnu_java_beans_decoder_ByteHandler_H_
#define _JC_gnu_java_beans_decoder_ByteHandler_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_ByteHandler$sub_refs	_jc_gnu_java_beans_decoder_ByteHandler$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_ByteHandler$sub_nonrefs	_jc_gnu_java_beans_decoder_ByteHandler$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ByteHandler$refs	_jc_gnu_java_beans_decoder_ByteHandler$refs;
typedef struct _jc_gnu_java_beans_decoder_ByteHandler$nonrefs	_jc_gnu_java_beans_decoder_ByteHandler$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ByteHandler$object	_jc_gnu_java_beans_decoder_ByteHandler$object;

typedef const struct _jc_gnu_java_beans_decoder_ByteHandler$vmethods	_jc_gnu_java_beans_decoder_ByteHandler$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_ByteHandler$vtable	_jc_gnu_java_beans_decoder_ByteHandler$vtable;
typedef const struct _jc_gnu_java_beans_decoder_ByteHandler$vtype	_jc_gnu_java_beans_decoder_ByteHandler$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_ByteHandler$method$_init$7d8397207e40a3b4(_jc_env *, struct _jc_gnu_java_beans_decoder_ByteHandler$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_ByteHandler$method$parse$d4a2df662e34a121(_jc_env *, struct _jc_gnu_java_beans_decoder_ByteHandler$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_ByteHandler$method_info$parse$d4a2df662e34a121;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_ByteHandler$vmethods {
	struct _jc_java_lang_Object$object	*(*parse$d4a2df662e34a121)(_jc_env *, struct _jc_gnu_java_beans_decoder_ByteHandler$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_ByteHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractElementHandler$vmethods	gnu_java_beans_decoder_AbstractElementHandler;
	_jc_gnu_java_beans_decoder_SimpleHandler$vmethods	gnu_java_beans_decoder_SimpleHandler;
	_jc_gnu_java_beans_decoder_ByteHandler$vmethods	gnu_java_beans_decoder_ByteHandler;
};

// Vtype
struct _jc_gnu_java_beans_decoder_ByteHandler$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_ByteHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ByteHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ByteHandler$refs {
    _jc_gnu_java_beans_decoder_ByteHandler$sub_refs	gnu_java_beans_decoder_ByteHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_refs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_refs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ByteHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ByteHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_nonrefs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_nonrefs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_ByteHandler$sub_nonrefs	gnu_java_beans_decoder_ByteHandler;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_ByteHandler$object {
	_jc_gnu_java_beans_decoder_ByteHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_ByteHandler$vtype	*vtype;
	_jc_gnu_java_beans_decoder_ByteHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_ByteHandler$vtype _jc_gnu_java_beans_decoder_ByteHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_ByteHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_ByteHandler$class_object;

#endif	/* _JC_gnu_java_beans_decoder_ByteHandler_H_ */
